@@ -2,6 +2,7 @@ package tim.prune.gui.colour;
 
 import java.awt.Color;
 
+import tim.prune.config.Config;
 import tim.prune.data.DataPoint;
 import tim.prune.data.Track;
 import tim.prune.data.TrackInfo;
@@ -25,9 +26,10 @@ public class SegmentColourer extends DiscretePointColourer
 	/**
 	 * Calculate the colours for each of the points in the given track
 	 * @param inTrackInfo track info object
+	 * @param inConfig config object (not needed here)
 	 */
 	@Override
-	public void calculateColours(TrackInfo inTrackInfo)
+	public void calculateColours(TrackInfo inTrackInfo, Config inConfig)
 	{
 		// initialise the array to the right size
 		Track track = inTrackInfo == null ? null : inTrackInfo.getTrack();
